### A2

Check the heading levels of concat file.

There may be images:

![Caption Text Blue](images/blue.png "Alt Text Blue")

\scale=0.9

![Caption Text Blue Repeated Image](images/blue.png  "Alt Text Blue Same Repeated Image")

![](images/blue.png  "Alt Text Blue Same Repeated Image Caption Missing")

#### A2 level four

Tables maybe:

| Left | Middle | Right |
|:-----|:------:|------:|
| L1   |   M2   |    R3 |
| L4   |   M5   |    R6 |
| L7   |   M8   |    R9 |
| L10  |  M11   |   R12 |
| L13  |  M14   |   R15 |

Table: A caption for a table \label{table:left-middle-right}
